package LTSP_utils::ImportFile;

use 5.012003;
use strict;
use warnings;
use Moose;

our $VERSION = '0.01';

has 'src' => (isa => 'Str', is => 'rw', required => 1);
has 'dst' => (isa => 'Str', is => 'rw', required => 1);
has 'ip' => (isa => 'Str', is => 'rw', required => 1);

around BUILDARGS => sub {
	my $orig  = shift;
	my $class = shift;

	if ( @_ == 3 && !ref $_[0] && !ref $_[1] && !ref $_[2] ) {
		return $class->$orig( src => $_[0], dst => $_[1], ip => $_[2] );
	}
	else {
		return $class->$orig(@_);
	}
};

__PACKAGE__->meta->make_immutable;

1;
__END__

=encoding utf8

=head1 NAME

LTSP_utils::ImportFile - Perl extension for implement three value class as elements on config.default on tag CONF at LTSP configuration.

=head1 SYNOPSIS

use ImportFile;

my $importFile = ImportFile->new( '/KIWI/hosts', '/etc/hosts', '192.168.10.1');

=head1 DESCRIPTION

This package is the implementation of a simple three values class, used to store triads of impost files on LTSP config schema as B<source file>, B<destination file> and B<IP address>.

=head2 ATRIBUTES

=head3 src

Stores the path of the source file on the server.

=head3 dst

Stores the path of the destination file on the image.

=head3 ip

Stores the IP address from where the file can be downloaded.

=head1 SEE ALSO

LTSP 5 documentation (http://www.ltsp.org/).

=head1 AUTHOR

Jordi "Txor" Casas Ríos, E<lt>jcasas@opentrends.netE<gt>, openTrends Solucions i Sistemes, S.L.

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 Generalitat de Catalunya 

This file is part of Linkatedu_11_4.  

Linkatedu_11_4 is free software; you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free
Software Foundation; either version 3 of the License, or (at your option) any
later version.

Linkatedu_11_4 is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for further
details, currently published at http://www.gnu.org/licenses/gpl.txt or in the
gpl.txt in the ["legal" folder] of this distribution.

You should have received a copy of the GNU General Public License along with
this program; If not, see <http://www.gnu.org/licenses/>

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=cut
